@@ -7,7 +7,8 @@ var keyMap = {
 	ka : "colorAmbient", // Ambient color: Ka 1.000 1.000 1.000
 	ks : "colorSpecular", // Specular color: Ks 1.000 1.000 1.000
 	ns : "specularCoef", // Specular coefficient: Ns 154.000
-	Tr : "transparency", // Transparency: Tr 0.9 or d 0.9
+	tr : "transparency", // Transparency: Tr 0.9 or d 0.9
+	d : "transparency", // Transparency: Tr 0.9 or d 0.9
 	ni : "opticalDensity", // Optical density: Ni 1.0
 	map_kd : "mapDiffuse", // Diffuse texture: map_Kd texture_diffuse.jpg
 	map_ka : "mapAmbient", // Ambient texture: map_Ka texture_ambient.jpg
@@ -24,7 +25,10 @@ var keyMap = {
 COLORS = [0xeeeeee, 0xee0000, 0x00ee00, 0x0000ee, 0xeeee00, 0x00eeee, 0xee00ee];
 
 
-module.exports = function( obj, options ){
+module.exports = function( obj, data, options ){
+		// fallbacks
+		data = data || {};
+		options = options || {};
 		// get material file
 		var mtl = utils.file_ext( obj, ".mtl");
 		// first read mtl file (usually fine to read synchronously)
@@ -33,7 +37,7 @@ module.exports = function( obj, options ){
 			var mtl = fs.readFileSync( mtl, "utf-8");
 		}
 		// parse text into an meaningful object
-		var materials = parser(mtl);
+		var materials = parser(mtl, options);
 		//
 		return JSON.stringify( materials );
 };
@@ -43,7 +47,7 @@ module.exports = function( obj, options ){
 
 // Based on the parser of MTLLoader
 // Source: https://raw.github.com/mrdoob/three.js/master/examples/js/loaders/MTLLoader.js
-function parser( mtl ){
+function parser( mtl, options ){
 
 	var lines = mtl.split( "\n" );
 	var delimiter_pattern = /\s+/;
@@ -55,7 +59,7 @@ function parser( mtl ){
 		var line = lines[ i ];
 		line = line.trim();
 
-		if ( line.length === 0 || line.charAt( 0 ) === '#' ) {
+		if ( line.length === 0 || line.charAt( 0 ) === '#' || line.substr( 0, 2 ) === "//" ) {
 
 			// Blank line or comment ignore
 			continue;
@@ -95,14 +99,18 @@ function parser( mtl ){
 				// skip empty values
 				if( value == "" ) continue;
 
-				// is it neseccery to parse floats on number string?
+				// special conditions for transparency...
+				if( key == "tr" || key == "d" || key == "map_d" ){
+					materials[ index ]["transparent"] = true;
+					if( options.transparency == "invert" && !isNaN( parseFloat(value) ) ){
+						// invert value
+						value = 1.0 - parseFloat(value);
+					}
+				}
+
+				// is it necessary to parse floats on number string?
 				materials[ index ][ keyMap[key] ] = (isNaN( parseFloat(value) )) ? value : parseFloat(value);
 
-				// special cases:
-				// if TRANSPARENCY == "invert":
-				//    materials[value]["transparency"] = 1.0 - float(chunks[1])
-				// else:
-				//    materials[value]["transparency"] = float(chunks[1])
 
 			}
 
@@ -125,9 +133,10 @@ function generate_mtl(materials){
 	for( i in materials){
 		var material = materials[i];
 		mtl[i] = {
-			'DbgColor': generate_color(index)
+			'DbgName': i,
+			'DbgIndex': material,
+			'DbgColor': generate_color(material)
 		}
-		index++;
 	}
 	return mtl;
 }
