@@ -1,9 +1,9 @@
 // overwrite these options when initiating the lib
 module.exports = {
-	align : "none", 				// : center centerxz bottom top none
-	shading : "smooth", 		// : smooth flat
-	type : "ascii", 					// : ascii binary
-	transparency : "normal", 	// : normal invert
+	align : "none", 			// model alignment: center, centerxz, bottom, top, none
+	shading : "smooth", 		// export vertex normals: smooth, flat
+	type : "ascii", 			// export format: ascii, binary
+	transparency : "normal", 	// opacity calculation: normal, invert
 	truncate : false,
 	scale : 1.0,
 	framestep : 1,
@@ -13,4 +13,3 @@ module.exports = {
 	colors : [0xeeeeee, 0xee0000, 0x00ee00, 0x0000ee, 0xeeee00, 0x00eeee, 0xee00ee],
 	buffers : false
 }
-
